## 5/07/2018
## Analysis of the Leukemia Data
## This is R code fits the PO model with ICAR frailties in the paper
rm(list=ls())
library(coda)
library(survival)
library(spBayesSurv)
library(fields)
library(BayesX)
library(R2BayesX)
library(splines)

############## Read table ##############
data(LeukSurv);
d = LeukSurv[order(LeukSurv$district),]; n = nrow(d);
d$ID=1:n;
head(d); 
## get adjacency matrix
nwengland=read.bnd(system.file("otherdata/nwengland.bnd", 
                               package="spBayesSurv"));
adj.mat=bnd2gra(nwengland)
W = diag(diag(adj.mat)) - as.matrix(adj.mat);

##-------------PO-------------------##
# MCMC parameters
nburn=10000; nsave=2000; nskip=19; niter = nburn+nsave
mcmc=list(nburn=nburn, nsave=nsave, nskip=nskip, ndisplay=1000);
prior = list(maxL=15, a0=1, b0=1);
ptm<-proc.time()
res2 = survregbayes(formula = Surv(time, cens) ~ age + bspline(age, df = 3) +
                      wbc + bspline(wbc, df = 3) + tpi + bspline(tpi, df = 3) + sex +
                      frailtyprior("car", district),
                    survmodel="PO", data=d, prior=prior, mcmc=mcmc,
                    Proximity=W, dist="loglogistic");
#
sfit2=summary(res2); sfit2
systime2=proc.time()-ptm; systime2;
save.image("ResultPOcar-splines.RData")

############# BFs for testing nonlinearity #############.
res2$BF.bs

############# plot for non-linear fixed effect #############
x1=d$age;x2=d$wbc; x3=d$tpi;
xx1=seq(min(x1),max(x1),length=200); xx2=seq(min(x2),max(x2),length=200);
xx3=seq(min(x3),max(x3),length=200)
x1bs.pred=predict(bspline(x1, df = 3), xx1);
x1.pred = cbind(xx1,x1bs.pred);
x2bs.pred=predict(bspline(x2, df = 3), xx2);
x2.pred = cbind(xx2,x2bs.pred);
x3bs.pred=predict(bspline(x3, df = 3), xx3);
x3.pred = cbind(xx3,x3bs.pred);
par(mfrow=c(3,1))
x1coef=res2$beta[1:4,];
x2coef=res2$beta[5:8,];
x3coef=res2$beta[9:12,];
x1curves=x1.pred%*%x1coef;
x2curves=x2.pred%*%x2coef;
x3curves=x3.pred%*%x3coef;
x1.low=apply(x1curves, 1, function(x) quantile(x,0.025));
x1.upp=apply(x1curves, 1, function(x) quantile(x,0.975))
x2.low=apply(x2curves, 1, function(x) quantile(x,0.025));
x2.upp=apply(x2curves, 1, function(x) quantile(x,0.975))
x3.low=apply(x3curves, 1, function(x) quantile(x,0.025));
x3.upp=apply(x3curves, 1, function(x) quantile(x,0.975))
width=8; height=8;
pdf(file ="Leukemia-PO-CAR-Nonlinear-age.pdf", paper="special", width=width, height=height)
par(cex=1.5,mar=c(4.1,4.1,1,1),cex.lab=1.3,cex.axis=1.1)
plot(xx1,rowMeans(x1curves),xlab="age",ylab="bs(age)",ylim=c(-1,4), "l", lwd=3)
lines(xx1, x1.low, lty=3, lwd=2)
lines(xx1, x1.upp, lty=3, lwd=2)
dev.off()

pdf(file ="Leukemia-PO-CAR-Nonlinear-wbc.pdf", paper="special", width=width, height=height)
par(cex=1.5,mar=c(4.1,4.1,1,1),cex.lab=1.3,cex.axis=1.1)
plot(xx2,rowMeans(x2curves),xlab="wbc",ylab="bs(wbc)",ylim=c(-1,4), "l", lwd=3)
lines(xx2, x2.low, lty=3, lwd=2)
lines(xx2, x2.upp, lty=3, lwd=2)
dev.off()

pdf(file ="Leukemia-PO-CAR-Nonlinear-tpi.pdf", paper="special", width=width, height=height)
par(cex=1.5,mar=c(4.1,4.1,1,1),cex.lab=1.3,cex.axis=1.1)
plot(xx3,rowMeans(x3curves),xlab="tpi",ylab="bs(tpi)",ylim=c(-1,4), "l", lwd=3)
lines(xx3, x3.low, lty=3, lwd=2)
lines(xx3, x3.upp, lty=3, lwd=2)
dev.off()

